@@ -15,7 +15,7 @@ def test_stream():
     tmo.settings.set_thermo(['Water'], cache=True)
     stream = tmo.Stream(None, Water=1, T=300)
     assert [stream.chemicals.Water] == stream.available_chemicals
-    assert_allclose(stream.epsilon, 77.70030000000003)
+    assert_allclose(stream.epsilon, 77.744307)
     assert_allclose(stream.alpha * 1e6, 0.14330776454124503)
     assert_allclose(stream.nu, 8.799123532986536e-07)
     assert_allclose(stream.Pr, 6.14001869413997)
@@ -77,7 +77,7 @@ def test_multistream():
     tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True)
     stream = tmo.MultiStream(None, l=[('Water', 1)], T=300)
     assert [stream.chemicals.Water] == stream.available_chemicals
-    assert_allclose(stream.epsilon, 77.70030000000003)
+    assert_allclose(stream.epsilon, 77.744307)
     assert_allclose(stream.alpha * 1e6, 1.4330776454124502e-01)
     assert_allclose(stream.nu, 8.799123532986536e-07)
     assert_allclose(stream.Pr, 6.14001869413997)
@@ -109,9 +109,7 @@ def test_multistream():
         stream.set_property('invalid property', 10, 'kg/hr')
     with pytest.raises(ValueError):
         tmo.MultiStream(None, l=[('Water', 1)], units='kg')
-    
     stream.empty()
-    
     with pytest.raises(AttributeError):
         stream.mol = 1.
     with pytest.raises(AttributeError):
@@ -164,7 +162,11 @@ def test_multistream():
     with pytest.raises(UndefinedPhase):
         stream.imol['s', 'Octanol']
     
-        
+    # Other
+    stream = tmo.MultiStream(None, l=[('Water', 1)], T=300, units='g/s')
+    assert stream.get_flow('g/s', 'Water') == stream.F_mass / 3.6 == 1.
+    stream.empty()    
+    
 if __name__ == '__main__':
     test_stream()
     test_multistream()
\ No newline at end of file
