@@ -9,19 +9,10 @@
 """
 
 from . import functor
-from . import thermo_model
-from . import thermo_model_handle
-from . import handle_builder
 from . import phase_handle
 
 __all__ = (*functor.__all__,
-           *thermo_model.__all__,
-           *thermo_model_handle.__all__,
-           *handle_builder.__all__,
            *phase_handle.__all__)
 
 from .functor import *
-from .thermo_model import *
-from .thermo_model_handle import *
-from .handle_builder import *
 from .phase_handle import *
