@@ -10,6 +10,7 @@
 
 import matplotlib.pyplot as plt
 from typing import Iterable
+import matplotlib.ticker as ticker
 import numpy as np
 
 __all__ = (
@@ -23,10 +24,10 @@ __all__ = (
     'set_axes_ylabels',
 )   
 
-def set_font(font_size=10, family='sans-serif', font='Arial'):
+def set_font(size=10, family='sans-serif', font='Arial'):
     import matplotlib
-    font = {'size': font_size}
-    matplotlib.rc('font', **font)
+    fontkwargs = {'size': size}
+    matplotlib.rc('font', **fontkwargs)
     params = matplotlib.rcParams
     params['font.' + family] = font
     params['font.family'] = family
@@ -38,7 +39,9 @@ def set_figure_size(width=None, aspect_ratio=None, units=None):
     if aspect_ratio is None:
         aspect_ratio = 0.65
     if width is None:
-        width = 6.614
+        width = 6.6142
+    elif width == 'half':
+        width = 6.6142 / 2
     else:
         if units is not None:
             from thermosteam.units_of_measure import convert
@@ -47,28 +50,69 @@ def set_figure_size(width=None, aspect_ratio=None, units=None):
     params = matplotlib.rcParams
     params['figure.figsize'] = np.array([width, width * aspect_ratio])
 
+def set_ticks(ax, ticks, which='x', ticklabels=(),
+              labelrotation=0., ha=None, offset=False):
+    if which == 'x':
+        axis = ax.xaxis
+        set_ticks = plt.xticks
+        kwargs = dict(top=False)
+    elif which == 'y':
+        axis = ax.yaxis
+        set_ticks = plt.yticks
+        kwargs = dict(right=False)
+    else:
+        raise ValueError("which must be either 'x' or 'y'")
+    if offset:
+        ticks = np.array(ticks, float)
+        ticks_offset = np.zeros(len(ticks) - 1)
+        if len(ticks_offset) != 0:
+            ticks_offset[:] = ticks[:-1] + 0.5 * np.diff(ticks)
+        ax.tick_params(axis=which, which='major', length=4,
+                       direction="inout", **kwargs)
+        ax.tick_params(axis=which, which='minor', length=0,
+                       labelrotation=labelrotation, **kwargs)
+        set_ticks(ticks_offset, ())
+        if ticklabels:
+            axis.set_minor_locator(ticker.FixedLocator(ticks))
+            axis.set_minor_formatter(ticker.FixedFormatter(ticklabels))
+        ticks = ticks_offset
+    else:
+        set_ticks(ticks, ticklabels)
+        ax.tick_params(axis=which, direction="inout", length=4, 
+                       labelrotation=labelrotation, **kwargs)
+    if ha is not None:
+        for i in axis.get_majorticklabels():
+            i.set_ha(ha)
+    return ticks
+    
+
 def style_axis(ax=None, xticks=None, yticks=None, 
                xticklabels=True, yticklabels=True,
                top=True, right=True, trim_to_limits=False,
                xtick0=True, ytick0=True,
-               xtickf=True, ytickf=True): # pragma: no cover
+               xtickf=True, ytickf=True,
+               offset_xticks=False,
+               offset_yticks=False,
+               xrot=None, xha=None,
+               yrot=None, yha=None): # pragma: no cover
     if ax is None:
         ax = plt.gca()
     if xticks is None:
         xticks, xtext = plt.xticks()
     else:
-        xtext = xticklabels if isinstance(xticklabels, Iterable) else list(xticks)
+        xtext = xticks
+    xtext = xticklabels if isinstance(xticklabels, Iterable) else list(xtext)
     if yticks is None:
         yticks, ytext = plt.yticks()
         if not any([str(i) for i in ytext]): ytext = yticks
     else:
-        ytext = yticklabels if isinstance(yticklabels, Iterable) else list(yticks)
+        ytext = yticks
+    ytext = yticklabels if isinstance(yticklabels, Iterable) else list(ytext)
+        
     xtext = list(xtext)
     ytext = list(ytext)
     if trim_to_limits:
         style_plot_limits(xticks, yticks)
-        if yticks[0] == 0.:
-            yticks = yticks[1:]
     if not xtick0:
         xtext[0] = ''
     if not xtickf:
@@ -77,16 +121,16 @@ def style_axis(ax=None, xticks=None, yticks=None,
         ytext[0] = ''
     if not ytickf:
         ytext[-1] = ''
-    plt.xticks(xticks, xtext) if xticklabels else plt.xticks(xticks, ())
-    plt.yticks(yticks, ytext) if yticklabels else plt.yticks(yticks, ())
-    ax.tick_params(axis="x", top=False, direction="inout", length=4)
-    ax.tick_params(axis="y", right=False, direction="inout", length=4)
+    
+    xticks = set_ticks(ax, xticks, 'x', xtext, xrot, xha, offset_xticks)
+    yticks = set_ticks(ax, yticks, 'y', ytext, yrot, yha, offset_yticks)
     ax.zorder = 1
     xlim = plt.xlim()
     ylim = plt.ylim()
     axes = {'ax': ax}
     if right:
         x_twin = ax.twinx()
+        ax._cached_xtwin = x_twin
         axes['twinx'] = x_twin 
         plt.sca(x_twin)
         x_twin.tick_params(axis='y', right=True, direction="in", length=4)
@@ -95,13 +139,13 @@ def style_axis(ax=None, xticks=None, yticks=None,
         plt.yticks(yticks, ())
     if top:
         y_twin = ax.twiny()
+        ax._cached_ytwin = y_twin
         axes['twiny'] = y_twin 
         plt.sca(y_twin)
         y_twin.tick_params(axis='x', top=True, direction="in", length=4)
         y_twin.zorder = 2
         plt.xlim(xlim)
         plt.xticks(xticks, ())
-    
     return axes
     
 def style_plot_limits(xticks, yticks): # pragma: no cover
